@@ -15,6 +15,17 @@ OPENTELEMETRY_BEGIN_NAMESPACE
 namespace logs
 {
 #if OPENTELEMETRY_ABI_VERSION_NO < 2
+#  if defined(_MSC_VER)
+#    pragma warning(push)
+#    pragma warning(disable : 4996)
+#  elif defined(__GNUC__) && !defined(__clang__) && !defined(__apple_build_version__)
+#    pragma GCC diagnostic push
+#    pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+#  elif defined(__clang__) || defined(__apple_build_version__)
+#    pragma clang diagnostic push
+#    pragma clang diagnostic ignored "-Wdeprecated-declarations"
+#  endif
+
 /**
  * Handles event log record creation.
  **/
@@ -77,6 +88,14 @@ private:
   void IgnoreTraitResult(ValueType &&...)
   {}
 };
+
+#  if defined(_MSC_VER)
+#    pragma warning(pop)
+#  elif defined(__GNUC__) && !defined(__clang__) && !defined(__apple_build_version__)
+#    pragma GCC diagnostic pop
+#  elif defined(__clang__) || defined(__apple_build_version__)
+#    pragma clang diagnostic pop
+#  endif
 #endif
 }  // namespace logs
 OPENTELEMETRY_END_NAMESPACE
