@@ -127,15 +127,12 @@ int main(int argc, char **argv)
       opentelemetry::nostd::shared_ptr<context::propagation::TextMapPropagator>(
           new propagation::HttpTraceContext()));
   constexpr uint16_t default_port = 8800;
-  uint16_t port;
+  uint16_t port{default_port};
   if (argc > 1)
   {
     port = static_cast<uint16_t>(atoi(argv[1]));
   }
-  else
-  {
-    port = default_port;
-  }
+
   RunClient(port);
   CleanupTracer();
   return 0;
