@@ -3,6 +3,8 @@
 
 #pragma once
 
+#include <cstdint>
+#include <limits>
 #include "opentelemetry/exporters/otlp/otlp_grpc_client_options.h"
 #include "opentelemetry/version.h"
 
@@ -32,6 +34,13 @@ struct OPENTELEMETRY_EXPORT OtlpGrpcExporterOptions : public OtlpGrpcClientOptio
   OtlpGrpcExporterOptions &operator=(const OtlpGrpcExporterOptions &) = default;
   OtlpGrpcExporterOptions &operator=(OtlpGrpcExporterOptions &&)      = default;
   ~OtlpGrpcExporterOptions() override;
+
+  /** Collection Limits. No limit by default. */
+  std::uint32_t max_attributes           = std::numeric_limits<std::uint32_t>::max();
+  std::uint32_t max_events               = std::numeric_limits<std::uint32_t>::max();
+  std::uint32_t max_links                = std::numeric_limits<std::uint32_t>::max();
+  std::uint32_t max_attributes_per_event = std::numeric_limits<std::uint32_t>::max();
+  std::uint32_t max_attributes_per_link  = std::numeric_limits<std::uint32_t>::max();
 };
 
 }  // namespace otlp
