@@ -238,7 +238,7 @@ public:
   void stop() { m_reactor.stop(); }
 
 protected:
-  virtual void onSocketAcceptable(SocketTools::Socket socket) override
+  void onSocketAcceptable(SocketTools::Socket socket) override
   {
     LOG_TRACE("HttpServer: accepting socket fd=0x%llx", socket.m_sock);
     assert(std::find(m_listeningSockets.begin(), m_listeningSockets.end(), socket) !=
@@ -258,7 +258,7 @@ protected:
     }
   }
 
-  virtual void onSocketReadable(SocketTools::Socket socket) override
+  void onSocketReadable(SocketTools::Socket socket) override
   {
     LOG_TRACE("HttpServer: reading socket fd=0x%llx", socket.m_sock);
     // No thread-safety here!
@@ -286,7 +286,7 @@ protected:
     handleConnection(conn);
   }
 
-  virtual void onSocketWritable(SocketTools::Socket socket) override
+  void onSocketWritable(SocketTools::Socket socket) override
   {
     LOG_TRACE("HttpServer: writing socket fd=0x%llx", socket.m_sock);
 
@@ -308,7 +308,7 @@ protected:
     }
   }
 
-  virtual void onSocketClosed(SocketTools::Socket socket) override
+  void onSocketClosed(SocketTools::Socket socket) override
   {
     LOG_TRACE("HttpServer: closing socket fd=0x%llx", socket.m_sock);
     assert(std::find(m_listeningSockets.begin(), m_listeningSockets.end(), socket) ==
