@@ -6,6 +6,7 @@
 #include <memory>
 #include <vector>
 
+#include "opentelemetry/sdk/configuration/exemplar_filter.h"
 #include "opentelemetry/sdk/configuration/metric_reader_configuration.h"
 #include "opentelemetry/sdk/configuration/view_configuration.h"
 #include "opentelemetry/version.h"
@@ -16,14 +17,14 @@ namespace sdk
 namespace configuration
 {
 
-// YAML-SCHEMA: schema/meter_provider.json
+// YAML-SCHEMA: schema/meter_provider.yaml
 // YAML-NODE: MeterProvider
 class MeterProviderConfiguration
 {
 public:
   std::vector<std::unique_ptr<MetricReaderConfiguration>> readers;
   std::vector<std::unique_ptr<ViewConfiguration>> views;
-  // FIXME: exemplar_filter
+  ExemplarFilter exemplar_filter = ExemplarFilter::trace_based;
   // FIXME: meter_configurator
 };
 
