@@ -6,6 +6,7 @@
 #include <memory>
 #include <vector>
 
+#include "opentelemetry/sdk/configuration/cardinality_limits_configuration.h"
 #include "opentelemetry/sdk/configuration/metric_producer_configuration.h"
 #include "opentelemetry/sdk/configuration/metric_reader_configuration.h"
 #include "opentelemetry/sdk/configuration/metric_reader_configuration_visitor.h"
@@ -18,7 +19,7 @@ namespace sdk
 namespace configuration
 {
 
-// YAML-SCHEMA: schema/meter_provider.json
+// YAML-SCHEMA: schema/meter_provider.yaml
 // YAML-NODE: PeriodicMetricReader
 class PeriodicMetricReaderConfiguration : public MetricReaderConfiguration
 {
@@ -32,6 +33,7 @@ public:
   std::size_t timeout{0};
   std::unique_ptr<PushMetricExporterConfiguration> exporter;
   std::vector<std::unique_ptr<MetricProducerConfiguration>> producers;
+  std::unique_ptr<CardinalityLimitsConfiguration> cardinality_limits;
 };
 
 }  // namespace configuration
