@@ -7,6 +7,7 @@
 #include "opentelemetry/sdk/metrics/export/periodic_exporting_metric_reader.h"
 #include "opentelemetry/sdk/metrics/export/periodic_exporting_metric_reader_factory.h"
 #include "opentelemetry/sdk/metrics/export/periodic_exporting_metric_reader_options.h"
+#include "opentelemetry/sdk/metrics/export/periodic_exporting_metric_reader_runtime_options.h"
 #include "opentelemetry/sdk/metrics/metric_reader.h"
 #include "opentelemetry/sdk/metrics/push_metric_exporter.h"
 #include "opentelemetry/version.h"
@@ -19,10 +20,19 @@ namespace metrics
 
 std::unique_ptr<MetricReader> PeriodicExportingMetricReaderFactory::Create(
     std::unique_ptr<PushMetricExporter> exporter,
-    const PeriodicExportingMetricReaderOptions &option)
+    const PeriodicExportingMetricReaderOptions &options)
+{
+  PeriodicExportingMetricReaderRuntimeOptions runtime_options;
+  return Create(std::move(exporter), options, runtime_options);
+}
+
+std::unique_ptr<MetricReader> PeriodicExportingMetricReaderFactory::Create(
+    std::unique_ptr<PushMetricExporter> exporter,
+    const PeriodicExportingMetricReaderOptions &options,
+    const PeriodicExportingMetricReaderRuntimeOptions &runtime_options)
 {
   std::unique_ptr<MetricReader> reader(
-      new PeriodicExportingMetricReader(std::move(exporter), option));
+      new PeriodicExportingMetricReader(std::move(exporter), options, runtime_options));
   return reader;
 }
 
