@@ -1,13 +1,13 @@
 // Copyright The OpenTelemetry Authors
 // SPDX-License-Identifier: Apache-2.0
 
-#include <algorithm>
 #include <chrono>
 #include <memory>
 #include <ostream>
 #include <utility>
 #include <vector>
 
+#include "opentelemetry/common/timestamp.h"
 #include "opentelemetry/nostd/function_ref.h"
 #include "opentelemetry/nostd/string_view.h"
 #include "opentelemetry/sdk/common/global_log_handler.h"
@@ -20,7 +20,6 @@
 #include "opentelemetry/sdk/metrics/meter_context.h"
 #include "opentelemetry/sdk/metrics/metric_reader.h"
 #include "opentelemetry/sdk/metrics/state/metric_collector.h"
-#include "opentelemetry/sdk/resource/resource.h"
 #include "opentelemetry/version.h"
 
 OPENTELEMETRY_BEGIN_NAMESPACE
@@ -28,7 +27,6 @@ namespace sdk
 {
 namespace metrics
 {
-using opentelemetry::sdk::resource::Resource;
 
 MetricCollector::MetricCollector(opentelemetry::sdk::metrics::MeterContext *context,
                                  std::shared_ptr<MetricReader> metric_reader,
@@ -76,7 +74,7 @@ MetricProducer::Result MetricCollector::Produce() noexcept
     ScopeMetrics scope_metrics;
     scope_metrics.metric_data_ = std::move(metric_data);
     scope_metrics.scope_       = meter->GetInstrumentationScope();
-    if (!this->metric_filter_)
+    if (!metric_filter_)
     {
       resource_metrics.scope_metric_data_.emplace_back(std::move(scope_metrics));
       return true;
@@ -93,7 +91,7 @@ MetricProducer::Result MetricCollector::Produce() noexcept
       opentelemetry::nostd::string_view unit = metric.instrument_descriptor.unit_;
 
       MetricFilter::MetricFilterResult metric_filter_result =
-          this->metric_filter_->TestMetric(scope, name, type, unit);
+          metric_filter_->TestMetric(scope, name, type, unit);
       if (metric_filter_result == MetricFilter::MetricFilterResult::kAccept)
       {
         filtered_scope_metrics.metric_data_.emplace_back(std::move(metric));
@@ -109,7 +107,7 @@ MetricProducer::Result MetricCollector::Produce() noexcept
       {
         const PointAttributes &attributes = point_data_attr.attributes;
         MetricFilter::AttributesFilterResult attributes_filter_result =
-            this->metric_filter_->TestAttributes(scope, name, type, unit, attributes);
+            metric_filter_->TestAttributes(scope, name, type, unit, attributes);
         if (attributes_filter_result == MetricFilter::AttributesFilterResult::kAccept)
         {
           filtered_point_data_attrs.emplace_back(std::move(point_data_attr));
