@@ -93,3 +93,46 @@ TEST(ViewRegistry, FindNonExistingView)
   EXPECT_EQ(status, true);
 #endif
 }
+
+// Tests for ViewRegistry::AddView null parameter validation
+// These should log errors and ignore the call instead of throwing or aborting
+
+TEST(ViewRegistry, AddViewWithNullInstrumentSelector)
+{
+  ViewRegistry registry;
+  std::unique_ptr<MeterSelector> meter_selector{new MeterSelector("name", "version", "schema")};
+  std::unique_ptr<View> view{new View("test_view")};
+
+  // Should not throw or abort, just log and ignore
+  registry.AddView(nullptr, std::move(meter_selector), std::move(view));
+}
+
+TEST(ViewRegistry, AddViewWithNullMeterSelector)
+{
+  ViewRegistry registry;
+  std::unique_ptr<InstrumentSelector> instrument_selector{
+      new InstrumentSelector(InstrumentType::kCounter, "instrument_name", "unit")};
+  std::unique_ptr<View> view{new View("test_view")};
+
+  // Should not throw or abort, just log and ignore
+  registry.AddView(std::move(instrument_selector), nullptr, std::move(view));
+}
+
+TEST(ViewRegistry, AddViewWithNullView)
+{
+  ViewRegistry registry;
+  std::unique_ptr<InstrumentSelector> instrument_selector{
+      new InstrumentSelector(InstrumentType::kCounter, "instrument_name", "unit")};
+  std::unique_ptr<MeterSelector> meter_selector{new MeterSelector("name", "version", "schema")};
+
+  // Should not throw or abort, just log and ignore
+  registry.AddView(std::move(instrument_selector), std::move(meter_selector), nullptr);
+}
+
+TEST(ViewRegistry, AddViewWithAllNullParameters)
+{
+  ViewRegistry registry;
+
+  // Should not throw or abort, just log and ignore
+  registry.AddView(nullptr, nullptr, nullptr);
+}
